/******************************************************************************
  
       Module : scrdemo.h
  
        Title : Header file for SCREDIT field editing system demo version
  
  Description : Header file for SCREDIT field editing system demo version
  
 ******************************************************************************/
  
/* Constants to be used with the Boolean variable required. */
#ifndef         TRUE
#define         FALSE   0
#define         TRUE    1
#endif

/*  macros for creating a color attribute  */
#define 	attr(fore,back)  ((((back) << 4) | (fore)))
#define 	background(A) ((A & 0xF0) >> 4)
#define 	foreground(A) (A & 0x0F)

/*  border types for make_window */
#define 	No_Border	0
#define 	Single_Border	1
#define 	Double_Border	2

/*  values for enumerate in make_pulldown_menu */
#define 	No_Enumerate	-1		/* do not number selections */
#define 	Enum_0_Relative 0		/* number selections, 0 relative */
#define 	Enum_1_Relative 1		/* number selections, 1 relative */

/*  initialization codes defined */
#define 	UNINIT		0xFF
#define 	INITIALIZED	0x00
  
/*  Numeric values for Boolean Yes/No type fields */
#define         BOOL_BLANK      2       /* Blank field */
#define         BOOL_YES        TRUE    /* Yes answer  */
#define         BOOL_NO         FALSE   /* No answer   */

/*  structure definitions for windows */
typedef struct {
    char    init;                   /* is this window initialized?          */
    char    row;                    /* upper left row corner                */
    char    col;                    /* upper left column corner             */
    char    num_rows;               /* number of rows                       */
    char    num_cols;               /* number of columns                    */
    char    txt_attr;               /* screen color background/foreground   */
    char    bdr_type;               /* border type                          */
    char    bdr_attr;               /* border attribute                     */
    char    title[80];              /* window title                         */
  
    int     win_number;             /* number of saved window               */
    char far  *save_window;         /* saved text, etc. behind window       */
    unsigned int old_curs_type;     /* last cursor type                     */
    char    col_lwr;
    char    row_lwr;
    char    old_winleft;            /* old window settings                  */
    char    old_wintop;
    char    old_winright;
    char    old_winbottom;
    char    old_x;                  /* old x setting                        */
    char    old_y;                  /* old y setting                        */
    char    old_attrib;
}  WINDO;
  
typedef struct {
    char    init;                   /* has this been initialized?           */
    char    attrib;                 /* attribute of bar                     */
    char    norm_attrib;            /* attribute of selections - normal     */
    char    hilit_attrib;           /* attribute of selections - hilited    */
    char    lnorm_attrib;           /* attribute of hot letter - normal     */
    char    lhilit_attrib;          /* attribute of hot letter - hilited    */
    int     hot_active;             /* TRUE if 'hot' letters are active, FALSE otherwise */
    int     passkey;                /* TRUE if non-window controls are to
                                              be passed back to caller, otherwise
                                              FALSE                               */
    char  far **selections;         /* pointer to selections                */
  
    char    hot_letters[20];        /* 'hot' letters for the menu           */
    char    hot_pos[20];            /* array position of 'hot' letters      */
    char    selection_start[20];    /* columns each selection starts in on bar */
    int     cur_select;             /* current selection on screen          */
    int     max_selections;         /* maximum number of selections         */
    WINDO   save_win;               /* saved window                         */
}  POPBAR;
  
typedef struct {
    char    init;                   /* has this been initialized?           */
    char    row;                    /* upper left row corner                */
    char    col;                    /* upper left column corner             */
    char    attrib;                 /* attribute of bar                     */
    char    norm_attrib;            /* attribute of selections - normal     */
    char    hilit_attrib;           /* attribute of selections - hilited    */
    char    lnorm_attrib;           /* attribute of hot letter - normal     */
    char    lhilit_attrib;          /* attribute of hot letter - hilited    */
    char    bdr_type;               /* type of border                       */
    int     e_value;                /* value of variable enumerate          */
    int     passkey;                /* TRUE if non-window controls are to
                                              be passed back to caller, otherwise
                                              FALSE                               */
    int     hot_active;             /* TRUE if 'hot' letters are active, FALSE otherwise */
    char   far *title;              /* title for window                     */
    char  far **selections;         /* pointer to selections                */
  
    char    hot_letters[20];        /* 'hot' letters for the menu           */
    char    hot_pos[20];            /* array position of 'hot' letters      */
    int     cur_select;             /* current selection on screen          */
    int     max_selections;         /* maximum number of selections         */
    WINDO   save_win;               /* saved window                         */
}  PULLDOWN;

typedef struct opttype {
    char far	**option_list;
    char	option_select;
#if defined (__TINY__) || (__SMALL__) || (__MEDIUM__)
    int 	pad;
#endif
} OPTTYPE;
  
/*  Function Declarations  */
void save_status(void);
void restore_status(void);
void blank_status (void);
void note(char *msg);
void errmsg (char *msg);
void disp_prompts(void far (*scrnptr)());
void undisp_prompts(void far (*scrnptr)());
void disp_io_fields (void far (*scrnptr)(), void *struc_buf);
int edit_input_fields (void far (*flds)(), void *struc_buf, void far **offset);
WINDO far *make_window (WINDO far *win_buf);
void remove_window (WINDO far *win_buf);
int make_bar_menu (POPBAR far *bar_buf);
void remove_bar_menu (POPBAR far *bar_buf);
int make_pulldown_menu (PULLDOWN far *pulldown);
void remove_pulldown_menu (PULLDOWN far *pulldown);
void paint_bar_menu_select (POPBAR far *bar_buf, int prev_sel);

